# Simple Logger
This package is a simple yet complete logging management system for python based applications. 
* Logging to two streams is allowed, by default the first one is the standard output (terminal).
* Logging text formatting (text color, text weight, background color) is allowed.
* Adding as many logging levels and types as needed is possible.

## Installation
pip install pysimplelog

## Online Documentation
http://bachiraoun.github.io/pysimplelog/

## Author
Bachir Aoun



